| Title: | View AnnotationHub and ExperimentHub Resources Interactively |
|---|---|
| Description: | A package that allows interactive exploration of AnnotationHub and ExperimentHub resources. It uses DT / DataTable to display resources for multiple organisms. It provides template code for reproducibility and for downloading resources via the indicated Hub package. |
| Authors: | Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>), Vincent Carey [ctb] |
| Maintainer: | Marcel Ramos <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.13.1 |
| Built: | 2026-05-22 06:51:02 UTC |
| Source: | https://github.com/bioc/BiocHubsShiny |
The shiny app will allow the user to view a table of either AnnotationHub or ExperimentHub resources depending on the sidebar selection. It provides example code for downloading the selected resources.
BiocHubsShiny(...)BiocHubsShiny(...)
... |
Further arguments to the |
Note. The code here was adapted from interactiveDisplayBase and
?'display,Hub-method' which are now deprecated.
Mainly called for the side effect of displaying the shiny app in a browser
if (interactive()) { BiocHubsShiny() }if (interactive()) { BiocHubsShiny() }